'Licensed Materials - Property of IBM
'5725-F57 IBM BigFix Inventory
'
'(C) Copyright IBM Corp. 2017-2018.
'All Rights Reserved. US Government Users Restricted Rights - Use,
'duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
const HKEY_LOCAL_MACHINE = &H80000002
const oFileTypeText = 2

Function EscapeSpecialCharacters(name)
  EscapeSpecialCharacters = Replace(name,"&","&amp;")
  EscapeSpecialCharacters = Replace(EscapeSpecialCharacters,chr(34),"&quot;")
  EscapeSpecialCharacters = Replace(EscapeSpecialCharacters,"'","&apos;")
  EscapeSpecialCharacters = Replace(EscapeSpecialCharacters,"<","&lt;")
  EscapeSpecialCharacters = Replace(EscapeSpecialCharacters,">","&gt;")
End Function

Function TextBetween(text, patternBegin, patternEnd)
    posBegin = InStr(text, patternBegin)
    posEnd = InStr(text, patternEnd)
    If posBegin = 0 Or posEnd = 0 Then Exit Function
    posBegin = posBegin + Len(patternBegin)
    TextBetween = Mid(text, posBegin, posEnd - posBegin)
End Function 

Function AddLine(line)
	Dim signature
    signature = TextBetween(line, "<DisplayName>", "</Publisher>")
    If Not validPackages.Exists(signature) Then
        validPackages.Add signature, line
    ElseIf Mid(TextBetween(line, "<Name>", "</Name>"), 1, 1) = "{" Then
        WScript.Echo "Removing duplicate package: " & validPackages.Item(signature)
        validPackages.Remove signature
        validPackages.Add signature, line
    Else
        WScript.Echo "Removing duplicate package: " & line
    End If
End Function

strComputer = "."

' write to file
Dim sFile : sFile = WScript.Arguments.Item(0)
Dim oFile : Set oFile = CreateObject( "ADODB.Stream" ) 
oFile.Type    = oFileTypeText
oFile.Charset = "utf-8"
oFile.Open

' associative array for duplicates removal 
Dim validPackages : Set validPackages = CreateObject("Scripting.Dictionary")

' get the entry for OS from wmi
Set objWMIService = GetObject("winmgmts:{impersonationLevel=impersonate}!\\" & strComputer & "\root\cimv2")
Set colOS = objWMIService.ExecQuery ("Select Caption from Win32_OperatingSystem")
for each objOS in colOS
   osEntry = "<Key><Name>*</Name><DisplayName>" & EscapeSpecialCharacters(objOS.Caption) & "</DisplayName><DisplayVersion></DisplayVersion><Publisher>Microsoft Corporation</Publisher></Key>"
   AddLine osEntry
Next

set oWsh = createobject("wscript.shell")
Set oReg = GetObject("winmgmts:{impersonationLevel=impersonate}!\\" & strComputer & "\root\default:StdRegProv")

' get internet explorer info from registered application path
on error resume next
sAppPathsKey = oWsh.Regread("HKLM\SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\IEXPLORE.EXE\")
if err.number = 0 then 
   ' IE key found
   Set objFSO = CreateObject("Scripting.FileSystemObject")
   sVersion = EscapeSpecialCharacters(objFSO.GetFileVersion(sAppPathsKey))
   ieEntry =  "<Key><Name>*</Name><DisplayName>Internet Explorer " & sVersion & "</DisplayName><DisplayVersion>" & sVersion & "</DisplayVersion><Publisher>Microsoft Corporation</Publisher></Key>"
   AddLine ieEntry
end if
On Error GoTo 0

' get uninstall registry key entries
' check for both 32 and 64 bit OS 
arrKeyPath = Array("software\wow6432node\microsoft\windows\currentversion\uninstall","software\microsoft\windows\currentversion\uninstall")

For Each strKeyPath In arrKeyPath
   on error resume next
   mainKey = oWsh.Regread("HKLM\" & strKeyPath & "\")

   if err.number = 0 then 
   oReg.EnumKey HKEY_LOCAL_MACHINE, strKeyPath, arrSubKeys
      For Each subkey In arrSubKeys

         ' pull back all values of interest of out each uninstall key subkey
         On Error Resume Next
         sSystemComponent = oWsh.Regread("HKLM\" & strKeyPath & "\" & subkey & "\SystemComponent")
         If Err.Number = 0 Then
            ' SystemComponent found
         Else
            sSystemComponent = "-1"
         End If
         On Error GoTo 0

         On Error Resume Next
         sDisplayName = oWsh.Regread("HKLM\" & strKeyPath & "\" & subkey & "\DisplayName")
         If Err.Number = 0 Then
            ' DisplayName found
         Else
            sDisplayName = ""
         End If
         On Error GoTo 0

         On Error Resume Next
         sDisplayVersion = oWsh.Regread("HKLM\" & strKeyPath & "\" & subkey & "\DisplayVersion")
         If Err.Number = 0 Then
            ' DisplayVersion found
         Else
            sDisplayVersion = ""
         End If
         On Error GoTo 0

         On Error Resume Next
         sPublisher = oWsh.Regread("HKLM\" & strKeyPath & "\" & subkey & "\Publisher")
         If Err.Number = 0 Then
            ' Publisher found
         Else
            sPublisher = ""
         End If
         On Error GoTo 0

         ' concatenate entries into a single line for keys that meet the criteria below
         if (instr(subkey, "{") = 1 AND instr(subkey, "}") > 1 AND sSystemComponent <> "-1") OR (sSystemComponent <> "1" AND sDisplayName <> "") Then
            sDisplayName = EscapeSpecialCharacters(sDisplayName)
            sDisplayVersion = EscapeSpecialCharacters(sDisplayVersion)
            sPublisher = EscapeSpecialCharacters(sPublisher)
            entry = "<Key><Name>" & subkey & "</Name><DisplayName>" & sDisplayName & "</DisplayName><DisplayVersion>" & sDisplayVersion & "</DisplayVersion><Publisher>" & sPublisher & "</Publisher></Key>"
            AddLine entry
         end if
      Next
      on error goto 0

   end if
Next
on error goto 0

' get MSSQL instances from registry key entries
' check for both 32 and 64 bit OS 
arrKeyPath = Array("SOFTWARE\Microsoft\Microsoft SQL Server","SOFTWARE\Wow6432Node\Microsoft\Microsoft SQL Server")
sDisplayNameUnique = ""

For Each strKeyPath In arrKeyPath
   on error resume next
   mainKey = oWsh.Regread("HKLM\" & strKeyPath & "\")

   if err.number = 0 then 
      oReg.EnumKey HKEY_LOCAL_MACHINE, strKeyPath, arrSubKeys
      For Each subkey In arrSubKeys

         ' pull back all values of interest of out each key subkey
         On Error Resume Next
         sMssqlEdition = oWsh.Regread("HKLM\" & strKeyPath & "\" & subkey & "\Setup\Edition")
         If Err.Number = 0 Then
          ' Edition found
         Else
           sMssqlEdition = "-1"
         End If
         On Error GoTo 0

         On Error Resume Next
         sDisplayVersion = oWsh.Regread("HKLM\" & strKeyPath & "\" & subkey & "\Setup\Version")
         If Err.Number = 0 Then
            ' DisplayVersion found

            Select Case Left(sDisplayVersion,2)
               Case "8."
                  sMssqlVersion = "2000"
               Case "9."
                  sMssqlVersion = "2005"
               Case "10"
                  If Mid(sDisplayVersion,4,1) < 5 Then
                     sMssqlVersion = "2008"   
                  Else
                     sMssqlVersion = "2008 R2"
                  End If
               Case "11"
                  sMssqlVersion = "2012"
               Case "12"
                  sMssqlVersion = "2014"
               Case "13"
                  sMssqlVersion = "2016"
               Case Else
                  sMssqlVersion = ""
            End Select

            sDisplayName = "Microsoft SQL Server " & sMssqlVersion & " " & sMssqlEdition
            If sDisplayName <> sDisplayNameUnique Then
               sDisplayNameUnique = sDisplayName
               sPublisher = "Microsoft Corporation"
               mssqlEntry = "<Key><Name>*</Name><DisplayName>" & sDisplayName & "</DisplayName><DisplayVersion></DisplayVersion><Publisher>" & sPublisher & "</Publisher></Key>"
               AddLine mssqlEntry
            End If
         End If
         On Error GoTo 0

      Next
      on error goto 0

   end if
Next
on error goto 0

lineArr = validPackages.Items
For i = 0 To validPackages.Count - 1
    oFile.writeText(lineArr(i) & vbCrLf)
Next

oFile.SaveToFile sFile
oFile.Close 