@ECHO OFF
SETLOCAL EnableDelayedExpansion
CALL bin\tools.bat GetCurrentDate currentDate
CALL bin\tools.bat GetCurrentTime currentTime
CALL bin\tools.bat GetCurrentUNIXtimestamp currentUNIXTimestamp
SET currentTimestamp=%currentDate%_%currentTime%
SET FILE_EXTENSIONS_EXIST=false

SET longPath=%~dp0..
CALL bin\tools.bat GetShortPath scannerFullDir

CALL bin\tools.bat Log "Starting run_sw.bat"

:: Updating catalog version in computer.yml and extensions in fs_config.xml
IF NOT EXIST "%scannerDir%work\computer.yml" (
	CALL bin\tools.bat Log "The file computer.yml not found"
	ECHO computer.yml file not found. Please, run "%scannerDir%"setup.bat script
	ENDLOCAL & EXIT /B 1
	)

IF EXIST  "%scannerDir%config\CIT_catalog_WINDOWS.xml" (
	CALL bin\tools.bat Log "Runnig command: CSCRIPT //Nologo //B %scannerDir%bin\xmltools.vbs UpdateCatalogVersion %scannerDir%config\CIT_catalog_WINDOWS.xml %scannerDir%work\computer.yml"
	CSCRIPT //Nologo //B "%scannerDir%bin\xmltools.vbs" UpdateCatalogVersion "%scannerDir%config\CIT_catalog_WINDOWS.xml" "%scannerDir%work\computer.yml"
	IF ERRORLEVEL 1 (
		CALL bin\tools.bat Log "Updating catalog version failed"
		ECHO Updating catalog version failed
		ENDLOCAL & EXIT /B 1
	)
	FINDSTR /C:"Extensions:" "%scannerDir%config\CIT_catalog_WINDOWS.xml" | FINDSTR /C:"!--" | FINDSTR /C:"-->" 1>nul
	IF ERRORLEVEL 1 (
		CALL bin\tools.bat Log "Missing extensions in catalog file"
		ECHO The catalog file is incorrect - please check the server version
		ENDLOCAL & EXIT /B 1
	) ELSE (
		FINDSTR /C:"Extensions:" "%scannerDir%config\CIT_catalog_WINDOWS.xml" | FINDSTR /C:"!--" | FINDSTR /C:"-->" | FINDSTR /C:"*." 1>nul
		IF ERRORLEVEL 1 (
			CALL bin\tools.bat Log "Empty extension list in the catalog file - file system scan will be skipped"
			SET FILE_EXTENSIONS_EXIST=false
		) ELSE (
			SET FILE_EXTENSIONS_EXIST=true
		)
	)
	IF "%FILE_EXTENSIONS_EXIST%" == "true" (
		CALL bin\tools.bat Log "Running command: CSCRIPT //Nologo //B %scannerDir%bin\xmltools.vbs UpdateFileExtensions %scannerDir%config\CIT_catalog_WINDOWS.xml %scannerDir%config\fs_config.xml"
		CSCRIPT //Nologo //B "%scannerDir%bin\xmltools.vbs" UpdateFileExtensions "%scannerDir%config\CIT_catalog_WINDOWS.xml" "%scannerDir%config\fs_config.xml"
		IF ERRORLEVEL 1 (
			CALL bin\tools.bat Log "Updating file extensions failed"
			ECHO Updating catalog version failed
			ENDLOCAL & EXIT /B 1
		)
	)
) ELSE (
	CALL bin\tools.bat Log "The file %scannerDir%config\CIT_catalog_WINDOWS.xml not found"
	ECHO Catalog file %scannerDir%config\CIT_catalog_WINDOWS.xml not found. Please, copy the catalog file to %scannerDir%config directory
	ENDLOCAL & EXIT /B 1
)

:: Resetting CIT cache
CALL "%scannerDir%bin\tools.bat" Log "Running command: %scannerDir%cit\bin\wscanfs.exe -reset"
"%scannerDir%cit\bin\wscanfs.exe" -reset

:: Catalog scan
CALL "%scannerDir%bin\tools.bat" Log "Running command: %scannerDir%cit\bin\wscansw.exe -s -c %scannerDir%config\sw_config.xml -i %scannerDir%config\CIT_catalog_WINDOWS.xml -o %scannerDir%work\catalog_scan.xml -e %scannerDir%logs\catalog_scan_CIT_warnings.log"
ECHO Starting catalog based scan...
"%scannerDir%cit\bin\wscansw.exe" -s -c "%scannerDir%config\sw_config.xml" -i "%scannerDir%config\CIT_catalog_WINDOWS.xml" -o "%scannerDir%work\catalog_scan.xml" -e "%scannerDir%logs\catalog_scan_CIT_warnings.log"
SET rc=%ERRORLEVEL%
IF %rc% EQU 0 (
	CALL "%scannerDir%bin\tools.bat" Log "Catalog scan successful"
	ECHO Catalog based scan was successful
	COPY /Y /V "%scannerDir%work\catalog_scan.xml" "%scannerDir%work\package\catalog_scan.xml" 2>NUL 1>NUL
	COPY /Y /V "%scannerDir%work\catalog_scan.xml.sgn" "%scannerDir%work\archive\catalog_scan.xml.sgn" 2>NUL 1>NUL
) ELSE (
	CALL "%scannerDir%bin\tools.bat" Log "Catalog scan finished with return code: %rc%"
	ECHO Catalog based scan finished with return code: %rc%
	IF EXIST "%scannerDir%work\catalog_scan.xml" DEL /F /Q "%scannerDir%work\catalog_scan.xml"
	IF EXIST "%scannerDir%work\catalog_scan.xml.sgn" DEL /F /Q "%scannerDir%work\catalog_scan.xml.sgn"
	ENDLOCAL & EXIT /B 1
)

:: File system scan
IF "%FILE_EXTENSIONS_EXIST%" == "true" (
	CALL "%scannerDir%bin\tools.bat" Log "Running command: %scannerDir%cit\bin\wscanfs.exe -s -c %scannerDir%config\fs_config.xml -o %scannerDir%work\file_scan.xml -i -sa pathfilename"
	ECHO Starting file system scan...
	"%scannerDir%cit\bin\wscanfs.exe" -s -c "%scannerDir%config\fs_config.xml" -o "%scannerDir%work\file_scan.xml" -i -sa pathfilename
	SET rc=!ERRORLEVEL!
	IF !rc! EQU 0 (
		CALL "%scannerDir%bin\tools.bat" Log "File system scan successful"
		ECHO File system scan was successful
		COPY /Y /V "%scannerDir%work\file_scan.xml" "%scannerDir%work\package\file_scan.xml" 2>NUL 1>NUL
		COPY /Y /V "%scannerDir%work\file_scan.xml.sgn" "%scannerDir%work\archive\file_scan.xml.sgn" 2>NUL 1>NUL
	) ELSE (
		CALL "%scannerDir%bin\tools.bat" Log "File system scan finished with return code: %rc%"
		ECHO File system based scan finished with return code: %rc%
		IF EXIST "%scannerDir%work\file_scan.xml" DEL /F /Q "%scannerDir%work\file_scan.xml"
		IF EXIST "%scannerDir%work\file_scan.xml.sgn" DEL /F /Q "%scannerDir%work\file_scan.xml.sgn"
		ENDLOCAL & EXIT /B 1
	) 
)

:: ISO tag scan
CALL "%scannerDir%bin\tools.bat" Log "Running command: %scannerDir%cit\bin\wscanfs.exe -s -c %scannerDir%config\isotag_config.xml -o %scannerDir%work\isotag_scan.xml -i"
ECHO Starting ISO-tag scan...
"%scannerDir%cit\bin\wscanfs.exe" -s -c "%scannerDir%config\isotag_config.xml" -o "%scannerDir%work\isotag_scan.xml" -i
SET rc=%ERRORLEVEL%
IF %rc% EQU 0 (
	CALL "%scannerDir%bin\tools.bat" Log "ISO tag scan successful"
	ECHO ISO-tag scan was successful
	CALL "%scannerDir%bin\tools.bat" Log "Runnig command: CSCRIPT //Nologo //B %scannerDir%bin\parseTagsXmlAndPrepareZip.vbs %scannerDir%work\isotag_scan.xml %scannerDir%work\isotag_scan.zip %scannerDir%work"
	CSCRIPT //Nologo //B "%scannerDir%bin\parseTagsXmlAndPrepareZip.vbs" "%scannerDir%work\isotag_scan.xml" "%scannerDir%work\isotag_scan.zip" "%scannerFullDir%\work"
	SET rc1=!ERRORLEVEL!
	IF !rc1! GEQ 1 (
		CALL "%scannerDir%bin\tools.bat" Log "Preparing ISO tag archive failed with return code: !rc1!"
		ECHO The script preparing ISO-tag archive finished with return code: !rc1!
		DEL /F /Q "%scannerDir%work\isotag_scan.zip"
	) ELSE (
		CALL "%scannerDir%bin\tools.bat" Log "Preparing ISO tag archive successful"
		ECHO The script preparing ISO-tag archive was successful
		COPY /Y /V "%scannerDir%work\isotag_scan.zip" "%scannerDir%work\package\isotag_scan.zip" 2>NUL 1>NUL
		COPY /Y /V "%scannerDir%work\isotag_scan.xml" "%scannerDir%work\archive\isotag_scan.xml" 2>NUL 1>NUL
		COPY /Y /V "%scannerDir%work\isotag_scan.xml.sgn" "%scannerDir%work\archive\isotag_scan.xml.sgn" 2>NUL 1>NUL
	)
) ELSE (
	CALL "%scannerDir%bin\tools.bat" Log "ISO tag scan finished with return code: %rc%"
	ECHO ISO-tag scan finished with return code: %rc%
	IF EXIST "%scannerDir%work\isotag_scan.xml" DEL /F /Q "%scannerDir%work\isotag_scan.xml"
	IF EXIST "%scannerDir%work\isotag_scan.xml.sgn" DEL /F /Q "%scannerDir%work\isotag_scan.xml.sgn"
	ENDLOCAL & EXIT /B 1
)

:: Resetting CIT cache
CALL "%scannerDir%bin\tools.bat" Log "Running command: %scannerDir%cit\bin\wscanfs.exe -reset"
"%scannerDir%cit\bin\wscanfs.exe" -reset

:: Package scan
CALL "%scannerDir%bin\tools.bat" Log "Running command: CSCRIPT //Nologo %scannerDir%bin\packageData.vbs %scannerDir%work\package_scan.xml"
ECHO Starting package scan...
CSCRIPT //Nologo "%scannerDir%bin\packageData.vbs" "%scannerDir%work\package_scan.xml" > "%scannerDir%logs\packageData.log" 2>&1
SET rc=%ERRORLEVEL%
IF %rc% EQU 0 (
	CALL "%scannerDir%bin\tools.bat" Log "Package scan successful"
	ECHO Package scan was successful
	COPY /Y /V "%scannerDir%work\package_scan.xml" "%scannerDir%work\package\package_scan.xml" 2>NUL 1>NUL
) ELSE (
	CALL "%scannerDir%bin\tools.bat" Log "Package scan finished with return code: %rc%"
	ECHO Package scan finished with return code: %rc%
	ENDLOCAL & EXIT /B 1
)  

ENDLOCAL & EXIT /B 0