@ECHO OFF
SETLOCAL
PUSHD "%~dp0"

CALL bin\tools.bat CheckPermissions
SET rc=%ERRORLEVEL%
IF %rc% NEQ 0 (
	POPD
	ENDLOCAL
	EXIT /B %rc% 
)

SET scannerDir=.\

:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Set the output directory here (enter full path)
SET outputDir=output
:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::

SET logfile="%scannerDir%\logs\run_sw_and_pack.log"
CALL bin\tools.bat Log "Starting run_sw_and_pack.bat (windows 9.2.16.0-20190827-1723)"
CALL bin\tools.bat CheckIsoTag
SET rc=%ERRORLEVEL%
IF %rc% NEQ 0 (
	POPD
	ENDLOCAL
	EXIT /B %rc% 
)
CALL bin\tools.bat CheckConsole
SET rc=%ERRORLEVEL%
IF %rc% NEQ 0 (
		IF %rc% EQU 129 (
		CALL bin\tools.bat Log "Software scan script failed, 32 bits console was used on 64 bits system"
		ECHO Software scan script failed, 32 bits console was used on 64 bits system
		POPD
		ENDLOCAL
		EXIT /B %rc%
	) ELSE (
		CALL bin\tools.bat Log "Software scan script failed with error %rc%"
		ECHO Software scan script failed with error %rc%
		POPD
		ENDLOCAL
		EXIT /B %rc%
		) 
	)
	)
CALL bin\tools.bat Log "Checking console successful"
ECHO Starting software scan and package preparation

CALL bin\tools.bat GetCurrentDate currentDate
CALL bin\tools.bat GetCurrentTimeHHMM currentTime
SET currentTimestamp=%currentDate%%currentTime%

:: Run hardware scan in case there aren't any outputs
IF NOT EXIST "%scannerDir%work\hw_scans_unique\tlm_hw_*.xml" CALL "bin\run_hw.bat"

CALL bin\tools.bat Log "Running command: bin\run_sw.bat"
CALL "bin\run_sw.bat"
SET rc=%ERRORLEVEL%
IF %rc% NEQ 0 (
	CALL bin\tools.bat Log "Software scan script failed with error %rc%"
	ECHO Software scan script failed with error %rc%
	POPD
	ENDLOCAL
	EXIT /B %rc% 
	)
CALL bin\tools.bat Log "Software scan script succsessful"
ECHO Software scanners finished.

:: Pack the output files
CALL bin\tools.bat Log "Preparing the output package..."
ECHO Preparing the output package...

CALL bin\tools.bat Log "Running command: COPY /Y /V %scannerDir%work\computer.yml %scannerDir%work\package\computer.yml"
COPY /Y /V "%scannerDir%work\computer.yml" "%scannerDir%work\package\computer.yml" 2>NUL 1>NUL

CALL bin\tools.bat Log "Running command: bin\zip.exe -q -j -r work\package\source.zip work\archive\*"
bin\zip.exe -q -j -r work\package\source.zip work\archive\*

CALL bin\tools.bat Log "Running command: bin\zip.exe -q -j -r work\package\capacity.zip work\hw_scans_unique\*"
bin\zip.exe -q -j -r work\package\capacity.zip work\hw_scans_unique\*

set /p endpointid= <"%scannerDir%config\endpoint_id.txt"

CALL bin\tools.bat Log "Running command: bin\zip.exe -q -j -r %currentTimestamp%-%endpointid%.zip work\package\*"
bin\zip.exe -q -j -r "%outputDir%\%currentTimestamp%-%endpointid%.zip" work\package\*

CALL bin\tools.bat Log "Cleaning the output directories"
ECHO Package created. Cleaning up the output directories...

DEL /F /Q work\archive\*
DEL /F /Q work\package\*
DEL /F /Q work\hw_scans_unique\*
DEL /F /Q work\package_scan.xml
IF EXIST "%scannerDir%work\tlm_hw_last.filename" SET /p LAST_HW_SCAN_NAME=<"%scannerDir%work\tlm_hw_last.filename"
IF EXIST "%scannerDir%work\tlm_hw_last.filename" (
	IF EXIST "%scannerDir%work\tlm_hw_last.xml" (
		echo %LAST_HW_SCAN_NAME%
		COPY /Y /V "%scannerDir%work\tlm_hw_last.xml" "%scannerDir%work\hw_scans_unique\%LAST_HW_SCAN_NAME%" 2>NUL 1>NUL
	) ELSE (
		DEL /F /Q work\tlm_hw_last.xml
	)
) ELSE (
	DEL /F /Q work\tlm_hw_last.xml
)

CALL bin\tools.bat Log "run_sw_and_pack.bat ended"
ENDLOCAL
POPD
ECHO Software scan and preparing the output package finished