@ECHO OFF
SETLOCAL
PUSHD "%~dp0"

CALL bin\tools.bat CheckPermissions
SET rc=%ERRORLEVEL%
IF %rc% NEQ 0 (
	ENDLOCAL
	POPD
	EXIT /B %rc% 
)

IF NOT EXIST logs MKDIR logs
SET scannerDir=.\

SET longPath=%~dp0
CALL bin\tools.bat GetShortPath scannerFullDir

SET logfile="%scannerDir%\logs\setup.log"
CALL bin\tools.bat Log "Starting setup.bat (windows 9.2.16.0-20190827-1723)"
ECHO Starting configuration of IBM LMT/BFI Disconnected Scanner (windows 9.2.16.0-20190827-1723)
CALL bin\tools.bat CheckIsoTag
SET rc=%ERRORLEVEL%
IF %rc% NEQ 0 (
	ENDLOCAL
	POPD
	EXIT /B %rc% 
)
IF "%~1"=="" SET scheduleHWscan=1
IF /I "%~1"=="-noschedule" (
	CALL bin\tools.bat Log "The first script argument is: %~1"
	SET scheduleHWscan=0
	) ELSE (
	CALL bin\tools.bat Log "The first script argument is: %~1"
	SET scheduleHWscan=1
	)
CALL bin\tools.bat GetCurrentDate currentDate
CALL bin\tools.bat GetCurrentTime currentTime
SET currentTimestamp=%currentDate%_%currentTime%

CALL bin\tools.bat Log "Disconnected Scanner directory is %scannerFullDir%"
ECHO Disconnected Scanner will be configured in %scannerFullDir%

:: Create required folders
IF NOT EXIST cit MKDIR cit
IF NOT EXIST cit\bin MKDIR cit\bin
IF NOT EXIST output MKDIR output
IF NOT EXIST work MKDIR work
IF NOT EXIST work\archive MKDIR work\archive
IF NOT EXIST work\package MKDIR work\package
IF NOT EXIST work\hw_scans_unique MKDIR work\hw_scans_unique

:: Checking if catalog file exists
IF NOT EXIST  "%scannerDir%config\CIT_catalog_WINDOWS.xml" (
	CALL bin\tools.bat Log "The file %scannerDir%config\CIT_catalog_WINDOWS.xml not found"
	ECHO Catalog file %scannerDir%config\CIT_catalog_WINDOWS.xml not found. Please, copy the catalog file to %scannerDir%config directory
	ENDLOCAL
	POPD
	EXIT /B 1
	)

:: Stopping the ILMT/TAD4D 7.X agent
NET STOP tlmagent >NUL 2>&1

:: Collecting architecture info (32 vs 64 bits)
:: do not add space before || in the next line
REG Query "HKLM\Hardware\Description\System\CentralProcessor\0" | find /i "x86" > NUL && SET arch=w32|| SET arch=w64
CALL bin\tools.bat Log "Discovered system architecture is %arch%"
ECHO Discovered system architecture is %arch%

:: Copy required dlls first
xcopy /y "%scannerDir%cit_install\%arch%\*.dll" "%scannerDir%cit\bin" > "%scannerDir%logs\wcitinst_%currentTimestamp%.log"

:: Choosing the proper CIT installer and running it
CALL bin\tools.bat Log "Running command: %scannerDir%cit_install\%arch%\wcitinst.exe i LMT-DISCONNECTED -r -s %scannerDir%cit_install\%arch%\cit.spb -d %scannerDir%cit -c %scannerDir%logs -p > %scannerDir%logs\wcitinst_%currentTimestamp%.log"
ECHO Starting CIT installation...
"%scannerDir%cit_install\%arch%\wcitinst.exe" i LMT-DISCONNECTED -r -s "%scannerDir%cit_install\%arch%\cit.spb" -d "%scannerDir%cit" -c "%scannerDir%logs" -p >> "%scannerDir%logs\wcitinst_%currentTimestamp%.log"
SET rc=%ERRORLEVEL%
IF %rc% NEQ 0 (
	CALL bin\tools.bat Log "CIT installation failed with error %rc%"
	ECHO CIT installation failed with error %rc% & echo. & echo.
	ENDLOCAL
	POPD
	EXIT /B %rc% 
	)
		
CALL bin\tools.bat Log "CIT installation successful"	
ECHO CIT installation successful

:: Collecting the data required for computer.yml by running initial hardware scan
CALL bin\tools.bat Log "Running command: %scannerDir%bin\run_hw.bat"
ECHO Running initial hardware scan...
CALL "bin\run_hw.bat" internal
SET rc=%ERRORLEVEL%
IF %rc% NEQ 0 (
	CALL bin\tools.bat Log "Initial hardware scan failed with error %rc%"
	ECHO Initial hardware scan failed with error %rc% & echo. & echo.
	ENDLOCAL
	POPD
	EXIT /B %rc% 
	)
CALL bin\tools.bat Log "Initial hardware scan successful"
ECHO Initial hardware scan successful

:: Generating endpoint ID
CALL bin\tools.bat GetMachineGuid machineGuid
CALL bin\tools.bat GetCurrentUNIXtimestamp currentUNIXTimestamp
IF NOT EXIST "%scannerDir%config\endpoint_id.txt" (
	ECHO. 2>"%scannerDir%config\endpoint_id.txt"
	ECHO %computername%-%machineGuid%-%currentUNIXTimestamp%>"%scannerDir%config\endpoint_id.txt"
)

:: Preparing computer.yml by calling tools VBS script 
CALL bin\tools.bat Log "Running command: CSCRIPT //Nologo //B bin\xmltools.vbs PrepareComputerYML work\tlm_hw_last.xml work\computer.yml config\endpoint_id.txt"
ECHO Preparing computer.yml file...
CSCRIPT //Nologo //B bin\xmltools.vbs PrepareComputerYML work\tlm_hw_last.xml work\computer.yml config\endpoint_id.txt
SET rc=%ERRORLEVEL%
IF %rc% NEQ 0 (
	CALL bin\tools.bat Log "Preparing computer.yml failed with error %rc%"
	ECHO Preparing computer.yml failed with error %rc% & echo. & echo.
	ENDLOCAL
	POPD
	EXIT /B %rc% 
	)
CALL bin\tools.bat Log "Preparing computer.yml successful"
ECHO Preparing computer.yml successful

:: Scheduling capacity scan every 30 minutes
IF %scheduleHWscan% EQU 1 (
	CALL bin\tools.bat Log "Running command: SCHTASKS /CREATE /F /SC minute /MO 30 /TN IBM ILMT hardware capacity scan /TR WSCRIPT.EXE //Nologo //B %scannerFullDir%bin\schwrapper.vbs %scannerFullDir%bin\run_hw.bat"
	ECHO Scheduling hardware scans
	SCHTASKS /CREATE /F /RU system /SC minute /MO 30 /TN "IBM ILMT hardware capacity scan" /TR "WSCRIPT.EXE //Nologo //B \"%scannerFullDir%bin\schwrapper.vbs\" \"%scannerFullDir%bin\run_hw.bat\""
	) ELSE (
	CALL bin\tools.bat Log "Running command: SCHTASKS /DELETE /TN IBM ILMT hardware capacity scan /F"
	ECHO Option -noschedule was used
	SCHTASKS /DELETE /TN "IBM ILMT hardware capacity scan" /F >NUL 2>&1
) 

CALL bin\tools.bat Log "setup.bat ended"
ENDLOCAL
POPD
ECHO Configuration of IBM LMT/BFI Disconnected Scanner finished successfully & echo. & echo.